==> humhub-1.17.4.zip: humhub-1.17.4/protected/humhub/messages/nb-NO/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>Bekreft</strong> handling',
    '<strong>Latest</strong> updates' => '<strong>Siste</strong> oppdateringer',
    '<strong>Mail</strong> summary' => '<strong>E-post</strong>-sammendrag',
    'Actions' => 'Handlinger',
    'Add:' => 'Legg til:',
    'Administration' => 'Administrasjon',
    'All' => 'Alt',
    'Allow' => 'Tillat',
    'An error occurred while handling your last action. (Handler not found).' => 'En feil oppstod (Handler not found).',
    'An unexpected error occurred while loading the search result.' => 'En uventet feil oppstod ved lasting av søkeresultat.',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'En uventet feil oppstod. Hvis dette fortsetter å skje, ta kontakt med din administrator.',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'En serverfeil oppstod. Hvis dette fortsetter å skje, ta kontakt med din administrator.',
    'Back' => 'Tilbake',
    'Back to dashboard' => 'Tilbake til oversikten',
    'Cancel' => 'Avbryt',
    'Choose language:' => 'Velg Språk',
    'Close' => 'Lukk',
    'Collapse' => 'Trekk sammen',
    'Confirm' => 'Bekreft',
    'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'Innholdspåbyggets kilde må være forekomst av HActiveRecordContent eller HActiveRecordContentAddon!',
    'Copy to clipboard' => 'Kopier til utklippstavle',
    'Could not find content of addon!' => 'Kunne ikke finne innhold fra påbygget!',
    'Could not find requested page.' => 'Fant ikke forespurt side.',
    'Default' => 'Standard',
    'Delete' => 'Slett',
    'Deny' => 'Avvis',
    'Do you really want to perform this action?' => 'Vil du virkelig utføre denne handlingen?',
    'Edit' => 'Rediger',
    'Error' => 'Feil',
    'Error while running your last action (Invalid request method).' => 'Feil under forrige handling (Invalid request method).',
    'Error:' => 'Feil:',
    'Expand' => 'Utvid',
    'Export' => 'Eksporter',
    'Info:' => 'Info:',
    'Invalid request method!' => 'Ugyldig forespørselsmetode',
    'It looks like you may have taken the wrong turn.' => 'Her ble det krøll.',
    'Language' => 'Språk',
    'Loading...' => 'Laster...',
    'Login' => 'Logg inn',
    'Logo of {appName}' => 'Logo for {appName}',
    'Logout' => 'Logg ut',
    'Menu' => 'Meny',
    'Module is not enabled on this content container!' => 'Modulen er ikke aktivert for dette innholdet',
    'New profile image' => 'Nytt profilbilde',
    'Next' => 'Neste',
    'No error information given.' => 'Ingen feilinformasjon angitt.',
    'Oooops...' => 'Oooops...',
    'Open' => 'Åpne',
    'Please type at least 3 characters' => 'Vennligst tast inn minst 3 tegn',
    'Please type at least {count} characters' => 'Vennligst tast inn minst {count} tegn',
    'Powered by {name}' => 'Drevet av {name}',
    'Profile dropdown' => 'Profil nedtrekksmeny',
    'Profile picture of {displayName}' => 'Profilbilde for {displayName}',
    'Save' => 'Lagre',
    'Saved' => 'Lagret',
    'Search' => 'Søk',
    'Select Me' => 'Velg meg',
    'Settings' => 'Innstillinger',
    'Show less' => 'Vis færre',
    'Show more' => 'Vis flere',
    'Some files could not be uploaded:' => 'Noen filer kunne ikke lastes opp:',
    'Text could not be copied to clipboard' => 'Teksten kunne ikke kopieres til utklipstavlen',
    'Text has been copied to clipboard' => 'Teksten har blitt kopiert til utklipstavlen',
    'The date has to be in the past.' => 'Datoen må være i fortid.',
    'The file has been deleted.' => 'Filen er slettet.',
    'The requested resource could not be found.' => 'Forespurt ressurs ble ikke fnnet.',
    'The space has been archived.' => 'Gruppen er blitt arkivert.',
    'The space has been unarchived.' => 'Gruppen er hentet tilbake fra arkivet.',
    'Time Zone' => 'Tidssone',
    'Toggle comment menu' => 'Veksle kommentarmeny',
    'Toggle panel menu' => 'Veksle panelmeny',
    'Toggle post menu' => 'Veksle postmeny',
    'Toggle stream entry menu' => 'Veksle strømmenyen',
    'Unsubscribe' => 'Avslutt abonnement',
    'Upload' => 'Last opp',
    'Upload file' => 'Last opp fil',
    'You are not allowed to run this action.' => 'Du har ikke tillatelse til å utføre denne handlingen.',
    'Allow content from external source' => '',
    'Always allow content from this provider!' => '',
    'An unexpected error occurred. Please check whether your file exceeds the allowed upload limit of {maxUploadSize}.' => '',
    'Do you want to enable content from \'{urlPrefix}\'?' => '',
    'My Profile' => '',
    'No results' => '',
    'Search...' => '',
    'Show all results' => '',
    'Stop impersonation' => '',
    'Unsaved changes will be lost. Do you want to proceed?' => '',
    'verify your upload_max_filesize and post_max_size php settings.' => '',
    '{attribute} has been empty. The system-configured function to fill empty values has returned an invalid value. Please try again or contact your administrator.' => '',
    '{attribute} must be a string (UUID) or null; {type} given.' => '',
    '{attribute} must be an UUID or null. UUID has the format "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", where X = [a-fA-F0-9] and both curly brackets and delimiting dashes are optional.' => '',
    '{nFormatted}B' => '',
    '{nFormatted}K' => '',
    '{nFormatted}M' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/messages/nb-NO/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>Bekreft</strong> handling',
    '<strong>Latest</strong> updates' => '<strong>Siste</strong> oppdateringer',
    '<strong>Mail</strong> summary' => '<strong>E-post</strong>-sammendrag',
    'Actions' => 'Handlinger',
    'Add:' => 'Legg til:',
    'Administration' => 'Administrasjon',
    'All' => 'Alt',
    'Allow' => 'Tillat',
    'An error occurred while handling your last action. (Handler not found).' => 'En feil oppstod (Handler not found).',
    'An unexpected error occurred while loading the search result.' => 'En uventet feil oppstod ved lasting av søkeresultat.',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'En uventet feil oppstod. Hvis dette fortsetter å skje, ta kontakt med din administrator.',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'En serverfeil oppstod. Hvis dette fortsetter å skje, ta kontakt med din administrator.',
    'Back' => 'Tilbake',
    'Back to dashboard' => 'Tilbake til oversikten',
    'Cancel' => 'Avbryt',
    'Choose language:' => 'Velg Språk',
    'Close' => 'Lukk',
    'Collapse' => 'Trekk sammen',
    'Confirm' => 'Bekreft',
    'Content Addon source must be instance of ContentActiveRecord or ContentAddonActiveRecord!' => 'Innholdspåbyggets kilde må være forekomst av ContentActiveRecord eller ContentAddonActiveRecord!',
    'Copy to clipboard' => 'Kopier til utklippstavle',
    'Could not find content of addon!' => 'Kunne ikke finne innhold fra påbygget!',
    'Could not find requested page.' => 'Fant ikke forespurt side.',
    'Default' => 'Standard',
    'Delete' => 'Slett',
    'Deny' => 'Avvis',
    'Do you really want to perform this action?' => 'Vil du virkelig utføre denne handlingen?',
    'Edit' => 'Rediger',
    'Enter security code above' => 'tast inn sikkerhetskoden over',
    'Error' => 'Feil',
    'Error while running your last action (Invalid request method).' => 'Feil under forrige handling (Invalid request method).',
    'Error:' => 'Feil:',
    'Expand' => 'Utvid',
    'Export' => 'Eksporter',
    'Info:' => 'Info:',
    'Invalid request method!' => 'Ugyldig forespørselsmetode',
    'It looks like you may have taken the wrong turn.' => 'Her ble det krøll.',
    'Language' => 'Språk',
    'Loading...' => 'Laster...',
    'Login' => 'Logg inn',
    'Logo of {appName}' => 'Logo for {appName}',
    'Logout' => 'Logg ut',
    'Menu' => 'Meny',
    'Module is not enabled on this content container!' => 'Modulen er ikke aktivert for dette innholdet',
    'New profile image' => 'Nytt profilbilde',
    'Next' => 'Neste',
    'No error information given.' => 'Ingen feilinformasjon angitt.',
    'Oooops...' => 'Oooops...',
    'Open' => 'Åpne',
    'Please type at least 3 characters' => 'Vennligst tast inn minst 3 tegn',
    'Please type at least {count} characters' => 'Vennligst tast inn minst {count} tegn',
    'Powered by {name}' => 'Drevet av {name}',
    'Profile dropdown' => 'Profil nedtrekksmeny',
    'Profile picture of {displayName}' => 'Profilbilde for {displayName}',
    'Save' => 'Lagre',
    'Saved' => 'Lagret',
    'Search' => 'Søk',
    'Select Me' => 'Velg meg',
    'Settings' => 'Innstillinger',
    'Show less' => 'Vis færre',
    'Show more' => 'Vis flere',
    'Some files could not be uploaded:' => 'Noen filer kunne ikke lastes opp:',
    'Text could not be copied to clipboard' => 'Teksten kunne ikke kopieres til utklipstavlen',
    'Text has been copied to clipboard' => 'Teksten har blitt kopiert til utklipstavlen',
    'The date has to be in the past.' => 'Datoen må være i fortid.',
    'The file has been deleted.' => 'Filen er slettet.',
    'The requested resource could not be found.' => 'Forespurt ressurs ble ikke fnnet.',
    'The space has been archived.' => 'Gruppen er blitt arkivert.',
    'The space has been unarchived.' => 'Gruppen er hentet tilbake fra arkivet.',
    'Time Zone' => 'Tidssone',
    'Toggle comment menu' => 'Veksle kommentarmeny',
    'Toggle panel menu' => 'Veksle panelmeny',
    'Toggle post menu' => 'Veksle postmeny',
    'Toggle stream entry menu' => 'Veksle strømmenyen',
    'Unsubscribe' => 'Avslutt abonnement',
    'Upload' => 'Last opp',
    'Upload file' => 'Last opp fil',
    'You are not allowed to run this action.' => 'Du har ikke tillatelse til å utføre denne handlingen.',
    'Allow content from external source' => '',
    'Always allow content from this provider!' => '',
    'An unexpected error occurred. Please check whether your file exceeds the allowed upload limit of {maxUploadSize}.' => '',
    'Back to login' => '',
    'Do you want to enable content from \'{urlPrefix}\'?' => '',
    'I\'m not a robot' => '',
    'My Profile' => '',
    'No results' => '',
    'Search...' => '',
    'Show all results' => '',
    'Stop impersonation' => '',
    'Switch network' => '',
    'Unsaved changes will be lost. Do you want to proceed?' => '',
    'Verified' => '',
    'We couldn\'t verify that you\'re human. Please check the box again.' => '',
    'verify your upload_max_filesize and post_max_size php settings.' => '',
    '{attribute} has been empty. The system-configured function to fill empty values has returned an invalid value. Please try again or contact your administrator.' => '',
    '{attribute} must be a string (UUID) or null; {type} given.' => '',
    '{attribute} must be an UUID or null. UUID has the format "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", where X = [a-fA-F0-9] and both curly brackets and delimiting dashes are optional.' => '',
    '{nFormatted}B' => '',
    '{nFormatted}K' => '',
    '{nFormatted}M' => '',
];
